# -*- coding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function
from __future__ import unicode_literals

import pkg_resources


__version__ = pkg_resources.get_distribution('language_formatters_pre_commit_hooks').version
